[llvm-commits] CVS: llvm/include/llvm/Support/ConstantRange.h

Reid Spencer reid at x10sys.com
Wed Feb 28 10:57:53 PST 2007



Changes in directory llvm/include/llvm/Support:

ConstantRange.h updated: 1.16 -> 1.17
---
Log message:

For PR1205: http://llvm.org/PR1205 :
First round of ConstantRange changes. This makes all CR constructors use
only APInt and not use ConstantInt. Clients are adjusted accordingly.


---
Diffs of the changes:  (+5 -9)

 ConstantRange.h |   14 +++++---------
 1 files changed, 5 insertions(+), 9 deletions(-)


Index: llvm/include/llvm/Support/ConstantRange.h
diff -u llvm/include/llvm/Support/ConstantRange.h:1.16 llvm/include/llvm/Support/ConstantRange.h:1.17
--- llvm/include/llvm/Support/ConstantRange.h:1.16	Wed Feb 28 11:36:23 2007
+++ llvm/include/llvm/Support/ConstantRange.h	Wed Feb 28 12:57:32 2007
@@ -51,22 +51,18 @@
 
   /// Initialize a range to hold the single specified value.
   ///
-  ConstantRange(Constant *Value);
+  ConstantRange(const APInt &Value);
 
-  /// Initialize a range of values explicitly... this will assert out if
-  /// Lower==Upper and Lower != Min or Max for its type, if the two constants
-  /// have different types, or if the constant are not integral values.
-  ///
-  ConstantRange(Constant *Lower, Constant *Upper);
-
-  /// @brief Initialize a range of values explicitly.
+  /// @brief Initialize a range of values explicitly. This will assert out if
+  /// Lower==Upper and Lower != Min or Max value for its type. It will also
+  /// assert out if the two APInt's are not the same bit width.
   ConstantRange(const APInt& Lower, const APInt& Upper);
 
   /// Initialize a set of values that all satisfy the predicate with C. The
   /// predicate should be either an ICmpInst::Predicate or FCmpInst::Predicate
   /// value.
   /// @brief Get a range for a relation with a constant integral.
-  ConstantRange(unsigned short predicate, ConstantInt *C);
+  ConstantRange(unsigned short predicate, const APInt &C);
 
   /// getLower - Return the lower value for this range...
   ///






More information about the llvm-commits mailing list